histimator package
==================

Submodules
----------

histimator\.estimator module
----------------------------

.. automodule:: histimator.estimator
    :members:
    :undoc-members:
    :show-inheritance:

histimator\.iterpolation module
-------------------------------

.. automodule:: histimator.iterpolation
    :members:
    :undoc-members:
    :show-inheritance:

histimator\.models module
-------------------------

.. automodule:: histimator.models
    :members:
    :undoc-members:
    :show-inheritance:

histimator\.pdfs module
-----------------------

.. automodule:: histimator.pdfs
    :members:
    :undoc-members:
    :show-inheritance:

histimator\.util module
-----------------------

.. automodule:: histimator.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: histimator
    :members:
    :undoc-members:
    :show-inheritance:
